==> haskell-hi-file-parser-0.1.0.0-95-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hi-file-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hi-file-parser
version:              0.1.0.0
visibility:           public
id:                   hi-file-parser-0.1.0.0-4uVWTJblfCAes4wzYEtMZ
key:                  hi-file-parser-0.1.0.0-4uVWTJblfCAes4wzYEtMZ
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Hussein Ait-Lahcen
homepage:             https://github.com/commercialhaskell/stack#readme
synopsis:             Parser for GHC'\''s hi files
description:
    Please see the README on Github at <https://github.com/commercialhaskell/stack/blob/master/subs/hi-file-parser/README.md>

category:             Development
abi:                  2ca20891717efcf5719a6083be52bcd8
exposed:              True
exposed-modules:      HiFileParser
hidden-modules:       Paths_hi_file_parser
import-dirs:          /usr/lib/ghc-8.10.3/site-local/hi-file-parser-0.1.0.0
library-dirs:         /usr/lib/ghc-8.10.3/site-local/hi-file-parser-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/hi-file-parser-0.1.0.0
hs-libraries:         HShi-file-parser-0.1.0.0-4uVWTJblfCAes4wzYEtMZ
depends:
    base-4.14.1.0 binary-0.8.8.0 bytestring-0.10.12.0
    rio-0.1.19.0-393N4jWjFNEKwBxEbMML0x
    vector-0.12.1.2-HCJzCvMeU9f2WjtWVmO7dQ

haddock-interfaces:
    /usr/share/doc/haskell-hi-file-parser/html/hi-file-parser.haddock

haddock-html:         /usr/share/doc/haskell-hi-file-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hi-file-parser-0.1.0.0-96-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hi-file-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hi-file-parser
version:              0.1.0.0
visibility:           public
id:                   hi-file-parser-0.1.0.0-EgVb8dCrNp38cDX3Vq5PfK
key:                  hi-file-parser-0.1.0.0-EgVb8dCrNp38cDX3Vq5PfK
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Hussein Ait-Lahcen
homepage:             https://github.com/commercialhaskell/stack#readme
synopsis:             Parser for GHC'\''s hi files
description:
    Please see the README on Github at <https://github.com/commercialhaskell/stack/blob/master/subs/hi-file-parser/README.md>

category:             Development
abi:                  8029fdcdda2cf0e411c63a2184fbb3a7
exposed:              True
exposed-modules:      HiFileParser
hidden-modules:       Paths_hi_file_parser
import-dirs:          /usr/lib/ghc-8.10.3/site-local/hi-file-parser-0.1.0.0
library-dirs:         /usr/lib/ghc-8.10.3/site-local/hi-file-parser-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/hi-file-parser-0.1.0.0
hs-libraries:         HShi-file-parser-0.1.0.0-EgVb8dCrNp38cDX3Vq5PfK
depends:
    base-4.14.1.0 binary-0.8.8.0 bytestring-0.10.12.0
    rio-0.1.19.0-EzdCZI4b8zlDYlHx3I2H7t
    vector-0.12.1.2-H4eLF7dv8NOKyZpgYZDRLA

haddock-interfaces:
    /usr/share/doc/haskell-hi-file-parser/html/hi-file-parser.haddock

haddock-html:         /usr/share/doc/haskell-hi-file-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
